@@ -24,7 +24,8 @@
 */
 var NAVTREE =
 [
-  [ "Doxygen", "index.html", [
+  [ "Manual", "index.html", [
+    [ "Doxygen", "index.html", null ],
     [ "Installation", "install.html", [
       [ "Compiling from source on UNIX", "install.html#install_src_unix", null ],
       [ "Installing the binaries on UNIX", "install.html#install_bin_unix", null ],
@@ -57,6 +58,13 @@ var NAVTREE =
       ] ],
       [ "Anatomy of a comment block", "docblocks.html#docstructure", null ]
     ] ],
+    [ "Additional Documentation", "additional.html", [
+      [ "Custom Pages", "additional.html#custom_pages", null ],
+      [ "Scaling Up", "additional.html#scaling", [
+        [ "Automatically Adding Files", "additional.html#automatically_adding_files", null ],
+        [ "Side Panel Treeview", "additional.html#treeview", null ]
+      ] ]
+    ] ],
     [ "Markdown support", "markdown.html", [
       [ "Standard Markdown", "markdown.html#markdown_std", [
         [ "Paragraphs", "markdown.html#md_para", null ],
@@ -90,13 +98,14 @@ var NAVTREE =
         [ "Code Spans Limits", "markdown.html#mddox_code_spans", null ],
         [ "Lists Extensions", "markdown.html#mddox_lists", null ],
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
-        [ "Limits on markup scope", "markdown.html#mddox_limits", null ]
+        [ "Limits on markup scope", "markdown.html#mddox_limits", null ],
+        [ "Support for GitHub Alerts", "markdown.html#mddox_github_alerts", null ]
       ] ],
       [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
     [ "Grouping", "grouping.html", [
-      [ "Modules", "grouping.html#modules", null ],
+      [ "Topics", "grouping.html#topics", null ],
       [ "Member Groups", "grouping.html#memgroup", null ],
       [ "Subpaging", "grouping.html#subpaging", null ]
     ] ],
@@ -142,9 +151,9 @@ var NAVTREE =
       [ "The overall HTML output looks different, while I only wanted to use my own html header file", "faq.html#faq_html_header", null ],
       [ "Why does doxygen use Qt?", "faq.html#faq_use_qt", null ],
       [ "How can I exclude all test directories from my directory tree?", "faq.html#faq_excl_dir", null ],
-      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?", "faq.html#faq_class", null ],
+      [ "Doxygen automatically generates a link to the class MyClass somewhere in the running text....", "faq.html#faq_class", null ],
       [ "My favorite programming language is X. Can I still use doxygen?", "faq.html#faq_pgm_X", null ],
-      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJECT\"", "faq.html#faq_lex", null ],
+      [ "Help! I get the cryptic message \"input buffer overflow, can't enlarge buffer because scanner uses REJ...", "faq.html#faq_lex", null ],
       [ "When running make in the latex directory I get \"TeX capacity exceeded\". Now what?", "faq.html#faq_latex", null ],
       [ "Why are dependencies via STL classes not shown in the dot graphs?", "faq.html#faq_stl", null ],
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
@@ -196,7 +205,7 @@ var NAVTREE =
       [ "Configuration options related to the Perl module output", "config.html#config_perlmod", null ],
       [ "Configuration options related to the preprocessor", "config.html#config_preprocessor", null ],
       [ "Configuration options related to external references", "config.html#config_external", null ],
-      [ "Configuration options related to the dot tool", "config.html#config_dot", null ],
+      [ "Configuration options related to diagram generator tools", "config.html#config_dot", null ],
       [ "Examples", "config.html#config_examples", null ]
     ] ],
     [ "Special Commands", "commands.html", [
@@ -210,6 +219,20 @@ var NAVTREE =
       [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
       [ "\\showrefs", "commands.html#cmdshowrefs", null ],
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
+      [ "\\showinlinesource", "commands.html#cmdshowinlinesource", null ],
+      [ "\\hideinlinesource", "commands.html#cmdhideinlinesource", null ],
+      [ "\\includegraph", "commands.html#cmdincludegraph", null ],
+      [ "\\hideincludegraph", "commands.html#cmdhideincludegraph", null ],
+      [ "\\includedbygraph", "commands.html#cmdincludedbygraph", null ],
+      [ "\\hideincludedbygraph", "commands.html#cmdhideincludedbygraph", null ],
+      [ "\\directorygraph", "commands.html#cmddirectorygraph", null ],
+      [ "\\hidedirectorygraph", "commands.html#cmdhidedirectorygraph", null ],
+      [ "\\collaborationgraph", "commands.html#cmdcollaborationgraph", null ],
+      [ "\\hidecollaborationgraph", "commands.html#cmdhidecollaborationgraph", null ],
+      [ "\\inheritancegraph['{option}']", "commands.html#cmdinheritancegraph", null ],
+      [ "\\hideinheritancegraph", "commands.html#cmdhideinheritancegraph", null ],
+      [ "\\groupgraph", "commands.html#cmdgroupgraph", null ],
+      [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
       [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
@@ -234,6 +257,7 @@ var NAVTREE =
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
       [ "\\memberof <name>", "commands.html#cmdmemberof", null ],
+      [ "\\module <name>", "commands.html#cmdmodule", null ],
       [ "\\name [(header)]", "commands.html#cmdname", null ],
       [ "\\namespace <name>", "commands.html#cmdnamespace", null ],
       [ "\\nosubgrouping", "commands.html#cmdnosubgrouping", null ],
@@ -281,10 +305,11 @@ var NAVTREE =
       [ "\\exception <exception-object> { exception description }", "commands.html#cmdexception", null ],
       [ "\\if (section-label)", "commands.html#cmdif", null ],
       [ "\\ifnot (section-label)", "commands.html#cmdifnot", null ],
+      [ "\\important { important text }", "commands.html#cmdimportant", null ],
       [ "\\invariant { description of invariant }", "commands.html#cmdinvariant", null ],
       [ "\\note { text }", "commands.html#cmdnote", null ],
       [ "\\par [(paragraph title)] { paragraph }", "commands.html#cmdpar", null ],
-      [ "\\param '['dir']' <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
+      [ "\\param[<dir>] <parameter-name> { parameter description }", "commands.html#cmdparam", null ],
       [ "\\parblock", "commands.html#cmdparblock", null ],
       [ "\\endparblock", "commands.html#cmdendparblock", null ],
       [ "\\tparam <template-parameter-name> { description }", "commands.html#cmdtparam", null ],
@@ -322,19 +347,21 @@ var NAVTREE =
       [ "\\subsection <subsection-name> (subsection title)", "commands.html#cmdsubsection", null ],
       [ "\\subsubsection <subsubsection-name> (subsubsection title)", "commands.html#cmdsubsubsection", null ],
       [ "\\paragraph <paragraph-name> (paragraph title)", "commands.html#cmdparagraph", null ],
+      [ "\\subparagraph <subparagraph-name> (subparagraph title)", "commands.html#cmdsubparagraph", null ],
+      [ "\\subsubparagraph <subsubparagraph-name> (subsubparagraph title)", "commands.html#cmdsubsubparagraph", null ],
       [ "\\dontinclude['{lineno}'] <file-name>", "commands.html#cmddontinclude", null ],
       [ "\\include['{'option'}'] <file-name>", "commands.html#cmdinclude", null ],
       [ "\\includelineno <file-name>", "commands.html#cmdincludelineno", null ],
-      [ "\\includedoc <file-name>", "commands.html#cmdincludedoc", null ],
+      [ "\\includedoc['{'option'}'] <file-name>", "commands.html#cmdincludedoc", null ],
       [ "\\line ( pattern )", "commands.html#cmdline", null ],
       [ "\\skip ( pattern )", "commands.html#cmdskip", null ],
       [ "\\skipline ( pattern )", "commands.html#cmdskipline", null ],
       [ "\\snippet['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippet", null ],
       [ "\\snippetlineno <file-name> ( block_id )", "commands.html#cmdsnippetlineno", null ],
-      [ "\\snippetdoc <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
+      [ "\\snippetdoc['{'option'}'] <file-name> ( block_id )", "commands.html#cmdsnippetdoc", null ],
       [ "\\until ( pattern )", "commands.html#cmduntil", null ],
       [ "\\verbinclude <file-name>", "commands.html#cmdverbinclude", null ],
-      [ "\\htmlinclude [\"[block]\"] <file-name>", "commands.html#cmdhtmlinclude", null ],
+      [ "\\htmlinclude['[block]'] <file-name>", "commands.html#cmdhtmlinclude", null ],
       [ "\\latexinclude <file-name>", "commands.html#cmdlatexinclude", null ],
       [ "\\rtfinclude <file-name>", "commands.html#cmdrtfinclude", null ],
       [ "\\maninclude <file-name>", "commands.html#cmdmaninclude", null ],
@@ -356,6 +383,7 @@ var NAVTREE =
       [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
       [ "\\mscfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmscfile", null ],
       [ "\\diafile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddiafile", null ],
+      [ "\\doxyconfig <config_option>", "commands.html#cmddoxyconfig", null ],
       [ "\\e <word>", "commands.html#cmde", null ],
       [ "\\em <word>", "commands.html#cmdem", null ],
       [ "\\endcode", "commands.html#cmdendcode", null ],
@@ -376,7 +404,7 @@ var NAVTREE =
       [ "\\f]", "commands.html#cmdfbrclose", null ],
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
-      [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
+      [ "\\htmlonly['[block]']", "commands.html#cmdhtmlonly", null ],
       [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
@@ -424,7 +452,15 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.11 Series", "changelog.html#log_1_11", [
+        [ "Release 1.11.0", "changelog.html#log_1_11_0", null ]
+      ] ],
+      [ "1.10 Series", "changelog.html#log_1_10", [
+        [ "Release 1.10.0", "changelog.html#log_1_10_0", null ]
+      ] ],
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.8", "changelog.html#log_1_9_8", null ],
+        [ "Release 1.9.7", "changelog.html#log_1_9_7", null ],
         [ "Release 1.9.6", "changelog.html#log_1_9_6", null ],
         [ "Release 1.9.5", "changelog.html#log_1_9_5", null ],
         [ "Release 1.9.4", "changelog.html#log_1_9_4", null ],
@@ -473,8 +509,8 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"arch.html",
-"commands.html#cmdxmlinclude"
+"additional.html",
+"commands.html#cmdskip"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
